<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>{{ title }}</title>
    {% load static %}
    <link href="{% static 'apiview_doc/docs/layui/css/layui.css' %}" rel="stylesheet">
    <script src="{% static 'apiview_doc/docs/layui/layui.js' %}"></script>

</head>
<body>
<div class="layui-layout layui-layout-admin">
    <div class="layui-side layui-bg-black" style="width: 225px">
        <div class="layui-side-scroll">
            {% include "apiview_doc/docs/sidebar.html" %}
        </div>
    </div>

    <div class="layui-body layui-main-content ">
        <!-- 内容主体区域 -->

        <div class="layui-row">
            <div class="layui-col-xs6">
                {% include "apiview_doc/docs/content.html" %}
            </div>
            <div class="layui-col-xs6">
            </div>
        </div>
    </div>


</div>

</body>
<style>
    .layui-main-content {
        left: 225px;
        padding: 20px;
    }
    .layui-layout-admin .layui-body {
        top: 0;
    }
</style>
</html>