#!/user/bin/env python3
# -*- coding: utf-8 -*-
"""
--------------------------------------
    Author:     JiChao_Song
    Date  :     2021/12/14 13:46
    Desc  :
--------------------------------------
"""

from django.apps import AppConfig


class RestFrameworkConfig(AppConfig):
    name = 'apiview_doc'
    verbose_name = "Django APIVIEW DOC"
