html #layuicss-skincodecss {
    display: none;
    position: absolute;
    width: 1989px
}

.layui-code-h3, .layui-code-view {
    position: relative;
    font-size: 12px
}

.layui-code-view {
    display: block;
    margin: 10px 0;
    padding: 0;
    border: 1px solid #eee;
    border-left-width: 6px;
    background-color: #FAFAFA;
    color: #333;
    font-family: Courier New
}

.layui-code-h3 {
    padding: 0 10px;
    height: 40px;
    line-height: 40px;
    border-bottom: 1px solid #eee
}

.layui-code-h3 a {
    position: absolute;
    right: 10px;
    top: 0;
    color: #999
}

.layui-code-view .layui-code-ol {
    position: relative;
    overflow: auto
}

.layui-code-view .layui-code-ol li {
    position: relative;
    margin-left: 45px;
    line-height: 20px;
    padding: 0 10px;
    border-left: 1px solid #e2e2e2;
    list-style-type: decimal-leading-zero;
    *list-style-type: decimal;
    background-color: #fff
}

.layui-code-view .layui-code-ol li:first-child {
    padding-top: 10px
}

.layui-code-view .layui-code-ol li:last-child {
    padding-bottom: 10px
}

.layui-code-view pre {
    margin: 0
}

.layui-code-notepad {
    border: 1px solid #0C0C0C;
    border-left-color: #3F3F3F;
    background-color: #0C0C0C;
    color: #C2BE9E
}

.layui-code-notepad .layui-code-h3 {
    border-bottom: none
}

.layui-code-notepad .layui-code-ol li {
    background-color: #3F3F3F;
    border-left: none
}

.layui-code-demo .layui-code {
    visibility: visible !important;
    margin: -15px;
    border-top: none;
    border-right: none;
    border-bottom: none
}

.layui-code-demo .layui-tab-content {
    padding: 15px;
    border-top: none
}